### Extended Symbol Information, Type Hierarchy and Compact Overviews

January 11, 2026

Recent commits and a new plugin release provide major new features!

- Extended symbol information: The `find_symbol` and `find_referencing_symbols` tools (and their JetBrains variants) now can return more information about the symbol (specifically, docstrings and signatures).
- Type hierarchy tool: A new tool – exclusive to JetBrains mode – that can fetch a symbol's hierarchy, i.e. superclasses and subclasses, which is very useful in many situations.
- Compact overviews: The `get_symbols_overview` tools now return a much more compact representation, saving many tokens. The JetBrains variant of the tool can now return a file's docstring (LSP varian't can't do that yet).

For more detailed information, see our changelog.